@@ -1,12 +1,14 @@
 library(bbmle)
+old_opts <- options(digits=3)
 x <- 0:10
 y <- c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
 d <- data.frame(x,y)
 fits <- lapply(c("optim","nlm","nlminb"),
-       mle2,
-       minuslogl=y~dpois(lambda=ymax/(1+x/xhalf)),
-       start=list(ymax=15,xhalf=6),data=d,
-       method="Nelder-Mead") ## 'method' is ignored by nlm()/nlminb()
+               mle2,
+               minuslogl=y~dpois(lambda=ymax/(1+x/xhalf)),
+               start=list(ymax=15,xhalf=6),data=d,
+               method="Nelder-Mead") ## 'method' is ignored by nlm()/nlminb()
+
 sapply(fits,coef)
 sapply(fits,logLik)
 
@@ -19,3 +21,4 @@ sapply(fits,logLik)
 ## (fit2 <-  mle2(y~dpois(lambda=25/(1+x/xhalf)),
 ##              start=list(xhalf=5),
 ##              optimizer="optimize"))
+options(old_opts)
