@@ -1,5 +1,5 @@
 library(bbmle)
-
+old_opt <- options(digits=3)
 x <- 0:10
 y <- c(26, 17, 13, 12, 20, 5, 9, 8, 5, 4, 8)
 d <- data.frame(x,y)
@@ -20,3 +20,4 @@ fit2 <- mle2(y~dpois(lambda=exp(a+b*x)),start=list(a=0,b=2),data=d,
 pp <- profile(fit2,prof.lower=-0.2)
 stopifnot(min(subset(as.data.frame(pp),param=="b")$par.vals.b)==-0.2)
 ## note that b does go below -0.2 when profiling a ...
+options(old_opt)
